pub enum PlaybackEvent {
PlaybackStateChanged(PlaybackState),
LoopStateChanged(LoopState),
ShuffleStateChanged(ShuffleState),
QueueChanged(Vec<Track>),
PositionChanged(usize),
PlayerPositionChanged(Duration),
PlayerVolumeChanged(PlayerVolume),
RateChanged(PlaybackRate),
}Expand description
Event originating from the playback module of the daemon.
Variants
PlaybackStateChanged(PlaybackState)
Sent when the playback state changes, for instance when the player is paused.
LoopStateChanged(LoopState)
Sent when the loop state of the player changes.
ShuffleStateChanged(ShuffleState)
Sent when the shuffle state of the player changes.
QueueChanged(Vec<Track>)
Sent when the track queue changes.
PositionChanged(usize)
Sent when the current track changes.
PlayerPositionChanged(Duration)
Sent when the position of the player changes.
PlayerVolumeChanged(PlayerVolume)
Sent when the volume of the player changes.
RateChanged(PlaybackRate)
Sent when the playback rate of the player changes.