ShuffleState

Enum ShuffleState 

pub enum ShuffleState {
    Off,
    On,
}
Shuffle state of the player.

Variants



Off

Play tracks in their original order.

For example tracks from a playlist will be played in the order they appear in the playlist.



On

Shuffle the tracks in the queue.