pub enum SignedDuration {
Positive(Duration),
Negative(Duration),
}Expand description
Signed duration type used for seeking.
This is just a bare bones type that should only be used for
seeking player position, and not as a Duration replacement.
Variants
Implementations