PlaybackRate

Struct PlaybackRate 

pub struct PlaybackRate { /* private fields */ }
The speed at which tracks are played.

Rate of 1.0 will play tracks at their original speed, 2.0 will play them twice as fast, and 0.5 will slow them to half speed.

Implementations

Source

impl PlaybackRate

pub fn new(rate: f64, min: f64, max: f64) -> PlaybackRate

Create a new PlaybackRate struct.

pub fn is_in_range(&self, rate: f64) -> bool

Checks if the given rate value is in the allowed range.

pub fn set_value(&mut self, rate: f64)

Set the rate multiplier.

This value will be clamped with the min and max values.

pub fn get_value(&self) -> f64

Get the rate multiplier.

pub fn get_value_f32(&self) -> f32

Get the rate multiplier clamped to f32.

pub fn set_min(&mut self, min: f64)

Set the minimum acceptable value for the playback rate.

pub fn get_min(&self) -> f64

Get the minimum acceptable value for the playback rate.

pub fn set_max(&mut self, max: f64)

Set the maximum acceptable value for the playback rate.

pub fn get_max(&self) -> f64

Get the maximum acceptable value for the playback rate.