pub enum LoopState {
Off,
Track,
Playlist,
}Expand description
Specifies how the player loops playback.
Variants
Off
The playback will stop when there are no more tracks to play.
Track
The current track will start again from the beginning once it has finished playing.
Playlist
The playback will loop through the entire queue.