pub struct PlaybackRate { /* private fields */ }Expand description
The speed at which tracks are played.
Rate of 1.0 will play tracks at their original speed, 2.0 will play them twice as fast, and
0.5 will slow them to half speed.
Implementations
Sourceimpl PlaybackRate
impl PlaybackRate
Sourcepub fn new(rate: f64, min: f64, max: f64) -> PlaybackRate
pub fn new(rate: f64, min: f64, max: f64) -> PlaybackRate
Create a new PlaybackRate struct.
Sourcepub fn is_in_range(&self, rate: f64) -> bool
pub fn is_in_range(&self, rate: f64) -> bool
Checks if the given rate value is in the allowed range.
Sourcepub fn set_value(&mut self, rate: f64)
pub fn set_value(&mut self, rate: f64)
Set the rate multiplier.
This value will be clamped with the min and max values.
Sourcepub fn get_value_f32(&self) -> f32
pub fn get_value_f32(&self) -> f32
Get the rate multiplier clamped to f32.